#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 haskell-language-server
version:              2.3.0.0
visibility:           public
id:                   haskell-language-server-2.3.0.0-3aPOG70efl83l9qCHZDyhX
key:                  haskell-language-server-2.3.0.0-3aPOG70efl83l9qCHZDyhX
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             LSP server for GHC
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  0b7b6cace66ff0c28486c42204888dc1
exposed:              True
exposed-modules:      HlsPlugins Ide.Arguments Ide.Main Ide.Version
hidden-modules:       Paths_haskell_language_server
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/haskell-language-server-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-language-server
hs-libraries:         HShaskell-language-server-2.3.0.0-3aPOG70efl83l9qCHZDyhX
depends:
    aeson-pretty-0.8.10-8SJKEprh2mAKo9yf193p1I
    async-2.2.6-8zdvXX2Zsrb75FFkoyfONv base-4.18.2.1
    base16-bytestring-1.0.2.0-pqJwJeshH1IdI5VXEk8FQ bytestring-0.11.5.3
    containers-0.6.7 cryptohash-sha1-0.11.101.0-G8w7Wc1b4UEHVy78nb80eR
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz directory-1.3.8.5
    extra-1.7.16-78rWMJMvfkTD1P7HRrGqSG filepath-1.4.300.1 ghc-9.6.6
    ghcide-2.3.0.0-6w7l3MFr3s5GGmPeFyak7n
    githash-0.1.6.3-bHHaPHc40oCymgfU1ZWNs
    hie-bios-0.12.0-Go20lGxKPPZDuI66ar7jZX
    hiedb-0.4.3.0-1M3fPIp8Bux9vFwLxerRYA
    hls-alternate-number-format-plugin-2.3.0.0-H7b1Lpn1ZotK0z3BjfaaUa
    hls-cabal-fmt-plugin-2.3.0.0-Id0AJZKiHXV6yvGgdaQvyM
    hls-cabal-plugin-2.3.0.0-ECHoGZ4B0lpdeVgzxKdfg
    hls-call-hierarchy-plugin-2.3.0.0-JAcYktZz3ZbA0KKM96vAsl
    hls-change-type-signature-plugin-2.3.0.0-DBRMfoU3Zmx9faQz9pWU0U
    hls-class-plugin-2.3.0.0-70Zj2YqGscC5I4yAJGNcPU
    hls-code-range-plugin-2.3.0.0-kVrfDZ6SpbDY1cwMA1Gxm
    hls-eval-plugin-2.3.0.0-I1dAnBIDo6RCrLpUOMH2kv
    hls-explicit-fixity-plugin-2.3.0.0-1JENUAgvzytKmtVuHkaroj
    hls-explicit-imports-plugin-2.3.0.0-42vcVhiNgMuy4GGxRjlt7
    hls-explicit-record-fields-plugin-2.3.0.0-ASQOTiiv4a29wK74TpkFDP
    hls-fourmolu-plugin-2.3.0.0-1ce5Qk8UOLb1t8YR21RjRL
    hls-gadt-plugin-2.3.0.0-JYXkvpj01SCBg5Qo0oaaq0
    hls-graph-2.3.0.0-65WRushYxdZ4YlcNcFbBXT
    hls-hlint-plugin-2.3.0.0-B36vGZvunGd3CLJBYViodW
    hls-module-name-plugin-2.3.0.0-7uq2dmUxsT8GllCZHkdTB9
    hls-ormolu-plugin-2.3.0.0-2D5OyckWphfDN86pKUPx94
    hls-overloaded-record-dot-plugin-2.3.0.0-FxupIxPB73tG0cQpBt3VnR
    hls-plugin-api-2.3.0.0-LfFc7Z03YyoGYY0VVD4QTJ
    hls-pragmas-plugin-2.3.0.0-AxdDBjOwFAWFccncRPBwMu
    hls-qualify-imported-names-plugin-2.3.0.0-7rXWAMtPy0CJzVkehdrc2U
    hls-refactor-plugin-2.3.0.0-JacHenzGDM0CylEGY0SKVw
    hls-rename-plugin-2.3.0.0-FCZKyIvab41EutjNevsu8v
    hls-retrie-plugin-2.3.0.0-Lf3LTXciU6f8Ihiz4jcKMP
    hls-splice-plugin-2.3.0.0-CDWeDdJ80HCGKePD051LBP
    hls-stylish-haskell-plugin-2.3.0.0-6W7qT8SlM3Z1KmhbB1G3XO
    lsp-2.2.0.0-6LZ7pOCDgZ2AzF4Z9mZdB3
    optparse-applicative-0.18.1.0-1hpBcyZ9dkK8RGPfmI5i3r
    optparse-simple-0.1.1.4-5yftxuNmcLm2kPb3GWFNQz
    prettyprinter-1.7.1-AIpSGHD2G4p9DIqum0FCg8 process-1.6.19.0
    safe-exceptions-0.1.7.4-Cn5kfaxd0fGJ7b6k9JieJx
    sqlite-simple-0.4.19.0-5IuZa8Rs010JGS1nfgvvQt text-2.0.2
    unordered-containers-0.2.20.1-KOOMDe69vyW5LNgLyOaup0

haddock-interfaces:
    /usr/share/doc/haskell-language-server/html/haskell-language-server.haddock

haddock-html:         /usr/share/doc/haskell-language-server/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

